﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using System.Collections;

namespace InfragisticsSample2
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            this.ultraGrid1.DisplayLayout.Override.AllowAddNew = AllowAddNew.No;
            this.ultraGrid1.DisplayLayout.Override.AllowDelete = Infragistics.Win.DefaultableBoolean.False;
            this.ultraGrid1.DisplayLayout.Override.CellClickAction = CellClickAction.RowSelect;
            this.ultraGrid1.DisplayLayout.Override.AllowUpdate = Infragistics.Win.DefaultableBoolean.False;

            DataTable dt = new DataTable();
            dt.Columns.Add("Col1");
            dt.Columns.Add("Col2");
            dt.Columns.Add("Col3");

            DataRow dr = dt.NewRow();
            dr["Col1"] = "1";
            dr["Col2"] = "Col2Row1";
            dr["Col3"] = "Col3Row1";
            dt.Rows.Add(dr);

            dr = dt.NewRow();
            dr["Col1"] = "2";
            dr["Col2"] = "Col2Row2";
            dr["Col3"] = "Col3Row2";
            dt.Rows.Add(dr);

            dr = dt.NewRow();
            dr["Col1"] = "2";
            dr["Col2"] = "Col2Row3";
            dr["Col3"] = "Col3Row3";
            dt.Rows.Add(dr);

            dr = dt.NewRow();
            dr["Col1"] = "3";
            dr["Col2"] = "Col2Row4";
            dr["Col3"] = "Col3Row4";
            dt.Rows.Add(dr);

            dr = dt.NewRow();
            dr["Col1"] = "3";
            dr["Col2"] = "Col2Row4";
            dr["Col3"] = "Col3Row4";
            dt.Rows.Add(dr);

            dr = dt.NewRow();
            dr["Col1"] = "4";
            dr["Col2"] = "Col2Row4";
            dr["Col3"] = "Col3Row4";
            dt.Rows.Add(dr);

            this.ultraGrid1.DataSource = dt;
            this.ultraGrid1.DataBind();


            bool foundNext = false;
            bool foundPrev = false;

            for (int i = 0; i < this.ultraGrid1.KeyActionMappings.Count; i++)
            {

                if (this.ultraGrid1.KeyActionMappings[i].ActionCode == UltraGridAction.NextRowByTab)
                {
                    this.ultraGrid1.KeyActionMappings[i].StateDisallowed = 0;
                    foundNext = true;
                }
                else if (this.ultraGrid1.KeyActionMappings[i].ActionCode == UltraGridAction.PrevRowByTab)
                {
                    this.ultraGrid1.KeyActionMappings[i].StateDisallowed = 0;
                    foundPrev = true;
                }

                if (foundNext && foundPrev)
                    break;
            }

            this.ultraGrid1.DisplayLayout.Bands[0].Summaries.Add(SummaryType.Sum, this.ultraGrid1.DisplayLayout.Bands[0].Columns["Col1"]);

            this.ultraGrid1.DisplayLayout.Bands[0].Columns["Col2"].GroupByComparer = new GroupByComparer("Col1", "Sum");
        }
    }

    public class GroupByComparer : IComparer
    {
        #region declarations

        private decimal tempDecimal = 0;
        private int tempInt = 0;
        private DateTime tempDateTime = DateTime.MinValue;
        private string compareKey = string.Empty;
        private string summaryType = string.Empty;

        #endregion //declarations

        #region constructors

        public GroupByComparer(string compareKey, string summaryType)
        {
            this.compareKey = compareKey;
            this.summaryType = summaryType;
        }

        #endregion //constructors

        #region properties

        public string SummaryText
        {
            get
            {
                return this.compareKey + " (" + this.summaryType + ")";
            }
        }

        #endregion //properties

        #region methods

        public int Compare(object x, object y)
        {
            UltraGridGroupByRow grpByRowX = (UltraGridGroupByRow)x;
            UltraGridGroupByRow grpByRowY = (UltraGridGroupByRow)y;
            string objX = string.Empty;
            string objY = string.Empty;
            int index = -1;

            for (int i = 0; i < grpByRowX.Rows.SummaryValues.Count; i++)
            {
                if (grpByRowX.Rows.SummaryValues[i].SummarySettings.SourceColumn.Key == this.compareKey &&
                    grpByRowX.Rows.SummaryValues[i].SummarySettings.SummaryType.ToString() == this.summaryType)
                {
                    index = i;
                    break;
                }
            }

            if (index > -1)
            {
                if (grpByRowX.Rows.SummaryValues[index].Value != null)
                    objX = grpByRowX.Rows.SummaryValues[index].Value.ToString();

                if (grpByRowY.Rows.SummaryValues[index].Value != null)
                    objY = grpByRowY.Rows.SummaryValues[index].Value.ToString();
            }

            if (decimal.TryParse(objX, out this.tempDecimal) && decimal.TryParse(objY, out this.tempDecimal))
                return Decimal.Compare(Convert.ToDecimal(objX), Convert.ToDecimal(objY));
            else if (int.TryParse(objX, out this.tempInt) && int.TryParse(objY, out this.tempInt))
                return Decimal.Compare(Convert.ToInt32(objX), Convert.ToInt32(objY));
            else if (DateTime.TryParse(objX, out this.tempDateTime) && DateTime.TryParse(objY, out this.tempDateTime))
                return DateTime.Compare(Convert.ToDateTime(objX), Convert.ToDateTime(objY));
            else
                return string.Compare(objX, objY);
        }

        #endregion //methods
    }

}
